@@ -1,15 +1,10 @@
+// SPDX-License-Identifier: LGPL-2.1-or-later
 //
-// This file is part of the Marble Virtual Globe.
-//
-// This program is free software licensed under the GNU LGPL. You can
-// find a copy of this license in LICENSE.txt in the top directory of
-// the source code.
-//
-// Copyright 2006-2010 Torsten Rahn        <tackat@kde.org>
-// Copyright 2007      Inge Wallin         <ingwa@kde.org>
-// Copyright 2011-2013 Bernhard Beschow    <bbeschow@cs.tu-berlin.de>
-// Copyright 2012      Illya Kovalevskyy   <illya.kovalevskyy@gmail.com>
-// Copyright 2012      Mohammed Nafees     <nafees.technocool@gmail.com>
+// SPDX-FileCopyrightText: 2006-2010 Torsten Rahn <tackat@kde.org>
+// SPDX-FileCopyrightText: 2007 Inge Wallin <ingwa@kde.org>
+// SPDX-FileCopyrightText: 2011-2013 Bernhard Beschow <bbeschow@cs.tu-berlin.de>
+// SPDX-FileCopyrightText: 2012 Illya Kovalevskyy <illya.kovalevskyy@gmail.com>
+// SPDX-FileCopyrightText: 2012 Mohammed Nafees <nafees.technocool@gmail.com>
 //
 
 #include "QtMainWindow.h"
@@ -304,7 +299,7 @@ void MainWindow::createActions()
      m_copyMapAction->setStatusTip(tr("Copy a screenshot of the map"));
      connect(m_copyMapAction, SIGNAL(triggered()), this, SLOT(copyMap()));
 
-     m_osmEditAction = new QAction(QIcon(QStringLiteral(":/icons/edit-map.png")), tr("&Edit Map"), this );
+     m_osmEditAction = new QAction(QIcon(QStringLiteral(":/icons/edit-map.png")), tr("&Edit Map..."), this );
      m_osmEditAction->setShortcut(tr( "Ctrl+E" ) );
      m_osmEditAction->setStatusTip(tr( "Edit the current map region in an external editor" ) );
      updateMapEditButtonVisibility( m_controlView->marbleWidget()->mapThemeId() );
@@ -394,7 +389,7 @@ void MainWindow::createActions()
      connect(m_aboutQtAction, SIGNAL(triggered()), qApp, SLOT(aboutQt()));
 
      //Bookmark Actions
-     m_addBookmarkAction = new QAction(QIcon(QStringLiteral(":/icons/bookmark-new.png")), tr("&Add Bookmark"), this);
+     m_addBookmarkAction = new QAction(QIcon(QStringLiteral(":/icons/bookmark-new.png")), tr("Add &Bookmark..."), this);
      m_addBookmarkAction->setShortcut(tr("Ctrl+B"));
      m_addBookmarkAction->setStatusTip(tr("Add Bookmark"));
      connect( m_addBookmarkAction, SIGNAL(triggered()), this, SLOT(openEditBookmarkDialog()) );
@@ -408,7 +403,7 @@ void MainWindow::createActions()
      m_toggleBookmarkDisplayAction->setCheckable( true );
      connect( m_toggleBookmarkDisplayAction, SIGNAL(triggered(bool)), this, SLOT(showBookmarks(bool)) );
 
-     m_manageBookmarksAction = new QAction(QIcon(QStringLiteral(":/icons/bookmarks-organize.png")), tr("&Manage Bookmarks"), this);
+     m_manageBookmarksAction = new QAction(QIcon(QStringLiteral(":/icons/bookmarks-organize.png")), tr("&Manage Bookmarks..."), this);
      m_manageBookmarksAction->setStatusTip( tr( "Manage Bookmarks" ) );
      connect( m_manageBookmarksAction, SIGNAL(triggered()), this, SLOT(manageBookmarks()) );
      
