@@ -1,14 +1,9 @@
+// SPDX-License-Identifier: LGPL-2.1-or-later
 //
-// This file is part of the Marble Virtual Globe.
-//
-// This program is free software licensed under the GNU LGPL. You can
-// find a copy of this license in LICENSE.txt in the top directory of
-// the source code.
-//
-// Copyright 2004-2007 Torsten Rahn  <tackat@kde.org>
-// Copyright 2007      Inge Wallin   <ingwa@kde.org>
-// Copyright 2007      Thomas Zander <zander@kde.org>
-// Copyright 2010      Bastian Holst <bastianholst@gmx.de>
+// SPDX-FileCopyrightText: 2004-2007 Torsten Rahn <tackat@kde.org>
+// SPDX-FileCopyrightText: 2007 Inge Wallin <ingwa@kde.org>
+// SPDX-FileCopyrightText: 2007 Thomas Zander <zander@kde.org>
+// SPDX-FileCopyrightText: 2010 Bastian Holst <bastianholst@gmx.de>
 //
 
 #ifndef MARBLE_MAPVIEWWIDGET_H
@@ -31,8 +26,8 @@ class MARBLE_EXPORT MapViewWidget : public QWidget
 {
     Q_OBJECT
  public:
-    explicit MapViewWidget( QWidget *parent = 0, Qt::WindowFlags f = 0 );
-    ~MapViewWidget();
+    explicit MapViewWidget( QWidget *parent = nullptr, Qt::WindowFlags f = nullptr );
+    ~MapViewWidget() override;
 
     /**
      * @brief Set a MarbleWidget associated to this widget.
@@ -41,7 +36,7 @@ class MARBLE_EXPORT MapViewWidget : public QWidget
     void setMarbleWidget( MarbleWidget *widget, MapThemeManager *mapThemeManager );
 
 protected:
-    void resizeEvent(QResizeEvent *event);
+    void resizeEvent(QResizeEvent *event) override;
 
  public Q_SLOTS:
     void setMapThemeId( const QString & );
@@ -75,7 +70,6 @@ private Q_SLOTS:
     void mapThemeIdChanged( const QString& );
     void projectionChanged( Projection );
     void showMapWizard();
-    void showUploadDialog();
     void mapThemeDeleted();
 
  private:
