@@ -1,21 +1,7 @@
+// SPDX-FileCopyrightText: 2010 Jens-Michael Hoffmann <jmho@c-xx.com>
+// SPDX-FileCopyrightText: 2010-2012 Bernhard Beschow <bbeschow@cs.tu-berlin.de>
 //
-// This file is part of the Marble Virtual Globe.
-//
-// Copyright 2010 Jens-Michael Hoffmann <jmho@c-xx.com>
-// Copyright 2010-2012 Bernhard Beschow <bbeschow@cs.tu-berlin.de>
-//
-// This library is free software; you can redistribute it and/or
-// modify it under the terms of the GNU Lesser General Public
-// License as published by the Free Software Foundation; either
-// version 2.1 of the License, or (at your option) any later version.
-//
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-// Lesser General Public License for more details.
-//
-// You should have received a copy of the GNU Lesser General Public
-// License along with this library. If not, see <http://www.gnu.org/licenses/>.
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #ifndef MARBLE_TILELOADER_H
 #define MARBLE_TILELOADER_H
@@ -51,7 +37,7 @@ class TileLoader: public QObject
     };
 
     explicit TileLoader(HttpDownloadManager * const, const PluginManager * );
-    ~TileLoader();
+    ~TileLoader() override;
 
     QImage loadTileImage( GeoSceneTextureTileDataset const *textureData, TileId const & tileId, DownloadUsage const );
     GeoDataDocument* loadTileVectorData( GeoSceneVectorTileDataset const *vectorData, TileId const & tileId, DownloadUsage const usage );
