@@ -1,11 +1,6 @@
+// SPDX-License-Identifier: LGPL-2.1-or-later
 //
-// This file is part of the Marble Virtual Globe.
-//
-// This program is free software licensed under the GNU LGPL. You can
-// find a copy of this license in LICENSE.txt in the top directory of
-// the source code.
-//
-// Copyright 2013   Utku Aydın <utkuaydin34@gmail.com>
+// SPDX-FileCopyrightText: 2013 Utku Aydın <utkuaydin34@gmail.com>
 //
 
 #ifndef BOOKMARKSYNCMANAGER_H
@@ -29,7 +24,7 @@ class MARBLE_EXPORT BookmarkSyncManager : public QObject
 
 public:
     explicit BookmarkSyncManager( CloudSyncManager *cloudSyncManager );
-    ~BookmarkSyncManager();
+    ~BookmarkSyncManager() override;
 
     /**
      * Last time Marble synced everything up
