@@ -1,11 +1,6 @@
+// SPDX-License-Identifier: LGPL-2.1-or-later
 //
-// This file is part of the Marble Virtual Globe.
-//
-// This program is free software licensed under the GNU LGPL. You can
-// find a copy of this license in LICENSE.txt in the top directory of
-// the source code.
-//
-// Copyright 2009 Torsten Rahn <tackat@kde.org>
+// SPDX-FileCopyrightText: 2009 Torsten Rahn <tackat@kde.org>
 //
 
 
@@ -13,14 +8,13 @@
 #define MARBLE_GEODATAREGION_H
 
 #include "GeoDataObject.h"
-#include "GeoDataLatLonAltBox.h"
-#include "GeoDataLod.h"
-
 
 namespace Marble
 {
 
 class GeoDataFeature;
+class GeoDataLatLonAltBox;
+class GeoDataLod;
 class GeoDataRegionPrivate;
 
 /*!
@@ -74,13 +68,13 @@ class GEODATA_EXPORT GeoDataRegion : public GeoDataObject
 /*!
     \brief Destroys a Region object.
 */
-    virtual ~GeoDataRegion();
+    ~GeoDataRegion() override;
 
     
 /*!
     \brief Provides type information for downcasting a GeoNode
 */
-    virtual const char* nodeType() const;
+    const char* nodeType() const override;
 
     bool operator==( const GeoDataRegion &other ) const;
     bool operator!=( const GeoDataRegion &other ) const;
@@ -129,14 +123,14 @@ class GEODATA_EXPORT GeoDataRegion : public GeoDataObject
     \brief Serialize the Region to a stream.
     \param stream the stream.
 */
-    virtual void pack( QDataStream& stream ) const;
+    void pack( QDataStream& stream ) const override;
 
 
 /*!
     \brief Unserialize the Region from a stream.
     \param stream the stream.
 */
-    virtual void unpack( QDataStream& stream );
+    void unpack( QDataStream& stream ) override;
 
     GeoDataRegion &operator=( const GeoDataRegion& other );
 
