@@ -1,14 +1,9 @@
+// SPDX-License-Identifier: LGPL-2.1-or-later
 //
-// This file is part of the Marble Virtual Globe.
-//
-// This program is free software licensed under the GNU LGPL. You can
-// find a copy of this license in LICENSE.txt in the top directory of
-// the source code.
-//
-// Copyright 2008-2009      Patrick Spendrin  <ps_ml@gmx.de>
-// Copyright 2010           Thibaut Gridel <tgridel@free.fr>
-// Copyright 2011-2012      Bernhard Beschow <bbeschow@cs.tu-berlin.de>
-// Copyright 2014           Gábor Péterffy   <peterffy95@gmail.com>
+// SPDX-FileCopyrightText: 2008-2009 Patrick Spendrin <ps_ml@gmx.de>
+// SPDX-FileCopyrightText: 2010 Thibaut Gridel <tgridel@free.fr>
+// SPDX-FileCopyrightText: 2011-2012 Bernhard Beschow <bbeschow@cs.tu-berlin.de>
+// SPDX-FileCopyrightText: 2014 Gábor Péterffy <peterffy95@gmail.com>
 //
 
 #include "GeometryLayer.h"
@@ -51,7 +46,6 @@
 #include <OsmPlacemarkData.h>
 #include "StyleBuilder.h"
 #include "AbstractGeoPolygonGraphicsItem.h"
-#include "GeoDataRelation.h"
 
 // Qt
 #include <qmath.h>
