@@ -1,11 +1,6 @@
+// SPDX-License-Identifier: LGPL-2.1-or-later
 //
-// This file is part of the Marble Virtual Globe.
-//
-// This program is free software licensed under the GNU LGPL. You can
-// find a copy of this license in LICENSE.txt in the top directory of
-// the source code.
-//
-// Copyright 2009      Eckhart Wörner <ewoerner@kde.org>
+// SPDX-FileCopyrightText: 2009 Eckhart Wörner <ewoerner@kde.org>
 //
 
 #include "Provider_p.h"
@@ -65,4 +60,4 @@ Status Provider::status() const
 
 
 
-#include "Provider.moc"
+#include "moc_Provider.cpp"
