@@ -1,11 +1,6 @@
+// SPDX-License-Identifier: LGPL-2.1-or-later
 //
-// This file is part of the Marble Virtual Globe.
-//
-// This program is free software licensed under the GNU LGPL. You can
-// find a copy of this license in LICENSE.txt in the top directory of
-// the source code.
-//
-// Copyright 2015      Constantin Mihalache <mihalache.c94@gmail.com>
+// SPDX-FileCopyrightText: 2015 Constantin Mihalache <mihalache.c94@gmail.com>
 //
 
 #include "OpenLocationCodeSearchPlugin.h"
@@ -31,12 +26,12 @@ QString OpenLocationCodeSearchPlugin::guiString() const
 
 QString OpenLocationCodeSearchPlugin::nameId() const
 {
-    return "openlocation-code-search";
+    return QStringLiteral("openlocation-code-search");
 }
 
 QString OpenLocationCodeSearchPlugin::version() const
 {
-    return "1.0";
+    return QStringLiteral("1.0");
 }
 
 QString OpenLocationCodeSearchPlugin::description() const
@@ -46,13 +41,13 @@ QString OpenLocationCodeSearchPlugin::description() const
 
 QString OpenLocationCodeSearchPlugin::copyrightYears() const
 {
-    return "2015";
+    return QStringLiteral("2015");
 }
 
-QList<PluginAuthor> OpenLocationCodeSearchPlugin::pluginAuthors() const
+QVector<PluginAuthor> OpenLocationCodeSearchPlugin::pluginAuthors() const
 {
-    return QList<PluginAuthor>()
-            << PluginAuthor( QString::fromUtf8( "Constantin Mihalache" ), "mihalache.c94@gmail.com" );
+    return QVector<PluginAuthor>()
+            << PluginAuthor(QStringLiteral("Constantin Mihalache"), QStringLiteral("mihalache.c94@gmail.com"));
 }
 
 SearchRunner* OpenLocationCodeSearchPlugin::newRunner() const
